# Auto generated user stub using 'nbox jobs new' command
# project name: {{ project_name }}
# created time: {{ created_time }}
#   created by: {{ email_id }}
#
# > feeling stuck, start by populating the functions below <

import os

os.environ["NBOX_LOG_LEVEL"] = "INFO" # Keep it the way you like

from nbox import Operator

def get_op() -> Operator:
  """Function to initialising your job, it might require passing a bunch of arguments.
  Use this function to get the operator by manually defining things here"""
  # from nbox.nbxlib.ops import Magic
  # return Magic()

  # >>> YOUR CODE HERE <<< #

  return
