# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dag.proto',
  package='jobs.dag',
  syntax='proto3',
  serialized_options=b'Z0github.com/NimbleBoxAI/jobs-architecture/jobs_pb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tdag.proto\x12\x08jobs.dag\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9a\x01\n\x03\x44\x41G\x12+\n\x07symbols\x18\x01 \x03(\x0b\x32\x1a.jobs.dag.DAG.SymbolsEntry\x12&\n\tflowchart\x18\x02 \x01(\x0b\x32\x13.jobs.dag.Flowchart\x1a>\n\x0cSymbolsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.jobs.dag.Node:\x02\x38\x01\"\xe5\x01\n\tFlowchart\x12-\n\x05nodes\x18\x01 \x03(\x0b\x32\x1e.jobs.dag.Flowchart.NodesEntry\x12-\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\x1e.jobs.dag.Flowchart.EdgesEntry\x1a<\n\nNodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.jobs.dag.Node:\x02\x38\x01\x1a<\n\nEdgesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.jobs.dag.Edge:\x02\x38\x01\"\xa8\x01\n\x04\x45\x64ge\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12%\n\x04type\x18\x04 \x01(\x0e\x32\x17.jobs.dag.Edge.EdgeType\x12\x13\n\x0bnbox_string\x18\x05 \x01(\t\"8\n\x08\x45\x64geType\x12\x13\n\x0f\x45XECUTION_ORDER\x10\x00\x12\r\n\tBRANCHING\x10\x01\x12\x08\n\x04LOOP\x10\x02\"\xa2\x02\n\tRunStatus\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x06inputs\x18\x03 \x03(\x0b\x32\x1f.jobs.dag.RunStatus.InputsEntry\x12\x31\n\x07outputs\x18\x04 \x03(\x0b\x32 .jobs.dag.RunStatus.OutputsEntry\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe4\x02\n\x04\x43ode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0bnbox_string\x18\x03 \x01(\t\x12\x0e\n\x06lineno\x18\x04 \x01(\x05\x12\x12\n\ncol_offset\x18\x05 \x01(\x05\x12\x12\n\nend_lineno\x18\x06 \x01(\x05\x12\x16\n\x0e\x65nd_col_offset\x18\x07 \x01(\x05\x12*\n\x06inputs\x18\x08 \x03(\x0b\x32\x1a.jobs.dag.Code.InputsEntry\x12,\n\x07outputs\x18\t \x03(\x0b\x32\x1b.jobs.dag.Code.OutputsEntry\x12\"\n\nconditions\x18\n \x03(\x0b\x32\x0e.jobs.dag.Code\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x91\x02\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x65xecution_index\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08operator\x18\x04 \x01(\t\x12%\n\x04type\x18\x05 \x01(\x0e\x32\x17.jobs.dag.Node.NodeType\x12\x1c\n\x04info\x18\x06 \x01(\x0b\x32\x0e.jobs.dag.Code\x12\x13\n\x0bnbox_string\x18\x07 \x01(\t\x12\'\n\nrun_status\x18\x08 \x01(\x0b\x32\x13.jobs.dag.RunStatus\"A\n\x08NodeType\x12\x08\n\x04\x43ODE\x10\x00\x12\x06\n\x02OP\x10\x01\x12\x08\n\x04LOOP\x10\x02\x12\r\n\tBRANCHING\x10\x03\x12\n\n\x06RETURN\x10\x04\x42\x32Z0github.com/NimbleBoxAI/jobs-architecture/jobs_pbb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_EDGE_EDGETYPE = _descriptor.EnumDescriptor(
  name='EdgeType',
  full_name='jobs.dag.Edge.EdgeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EXECUTION_ORDER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRANCHING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOOP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=558,
  serialized_end=614,
)
_sym_db.RegisterEnumDescriptor(_EDGE_EDGETYPE)

_NODE_NODETYPE = _descriptor.EnumDescriptor(
  name='NodeType',
  full_name='jobs.dag.Node.NodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CODE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOOP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRANCHING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RETURN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1477,
  serialized_end=1542,
)
_sym_db.RegisterEnumDescriptor(_NODE_NODETYPE)


_DAG_SYMBOLSENTRY = _descriptor.Descriptor(
  name='SymbolsEntry',
  full_name='jobs.dag.DAG.SymbolsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='jobs.dag.DAG.SymbolsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='jobs.dag.DAG.SymbolsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=211,
)

_DAG = _descriptor.Descriptor(
  name='DAG',
  full_name='jobs.dag.DAG',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbols', full_name='jobs.dag.DAG.symbols', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flowchart', full_name='jobs.dag.DAG.flowchart', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DAG_SYMBOLSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=211,
)


_FLOWCHART_NODESENTRY = _descriptor.Descriptor(
  name='NodesEntry',
  full_name='jobs.dag.Flowchart.NodesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='jobs.dag.Flowchart.NodesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='jobs.dag.Flowchart.NodesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=381,
)

_FLOWCHART_EDGESENTRY = _descriptor.Descriptor(
  name='EdgesEntry',
  full_name='jobs.dag.Flowchart.EdgesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='jobs.dag.Flowchart.EdgesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='jobs.dag.Flowchart.EdgesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=443,
)

_FLOWCHART = _descriptor.Descriptor(
  name='Flowchart',
  full_name='jobs.dag.Flowchart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='jobs.dag.Flowchart.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edges', full_name='jobs.dag.Flowchart.edges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWCHART_NODESENTRY, _FLOWCHART_EDGESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=443,
)


_EDGE = _descriptor.Descriptor(
  name='Edge',
  full_name='jobs.dag.Edge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='jobs.dag.Edge.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='jobs.dag.Edge.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='jobs.dag.Edge.target', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='jobs.dag.Edge.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nbox_string', full_name='jobs.dag.Edge.nbox_string', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EDGE_EDGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=614,
)


_RUNSTATUS_INPUTSENTRY = _descriptor.Descriptor(
  name='InputsEntry',
  full_name='jobs.dag.RunStatus.InputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='jobs.dag.RunStatus.InputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='jobs.dag.RunStatus.InputsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=859,
)

_RUNSTATUS_OUTPUTSENTRY = _descriptor.Descriptor(
  name='OutputsEntry',
  full_name='jobs.dag.RunStatus.OutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='jobs.dag.RunStatus.OutputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='jobs.dag.RunStatus.OutputsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=907,
)

_RUNSTATUS = _descriptor.Descriptor(
  name='RunStatus',
  full_name='jobs.dag.RunStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='jobs.dag.RunStatus.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='jobs.dag.RunStatus.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='jobs.dag.RunStatus.inputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='jobs.dag.RunStatus.outputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RUNSTATUS_INPUTSENTRY, _RUNSTATUS_OUTPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=907,
)


_CODE_INPUTSENTRY = _descriptor.Descriptor(
  name='InputsEntry',
  full_name='jobs.dag.Code.InputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='jobs.dag.Code.InputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='jobs.dag.Code.InputsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=859,
)

_CODE_OUTPUTSENTRY = _descriptor.Descriptor(
  name='OutputsEntry',
  full_name='jobs.dag.Code.OutputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='jobs.dag.Code.OutputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='jobs.dag.Code.OutputsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=907,
)

_CODE = _descriptor.Descriptor(
  name='Code',
  full_name='jobs.dag.Code',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='jobs.dag.Code.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='jobs.dag.Code.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nbox_string', full_name='jobs.dag.Code.nbox_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lineno', full_name='jobs.dag.Code.lineno', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='col_offset', full_name='jobs.dag.Code.col_offset', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_lineno', full_name='jobs.dag.Code.end_lineno', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_col_offset', full_name='jobs.dag.Code.end_col_offset', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='jobs.dag.Code.inputs', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='jobs.dag.Code.outputs', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='jobs.dag.Code.conditions', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CODE_INPUTSENTRY, _CODE_OUTPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=1266,
)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='jobs.dag.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='jobs.dag.Node.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_index', full_name='jobs.dag.Node.execution_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='jobs.dag.Node.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='jobs.dag.Node.operator', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='jobs.dag.Node.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='jobs.dag.Node.info', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nbox_string', full_name='jobs.dag.Node.nbox_string', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_status', full_name='jobs.dag.Node.run_status', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NODE_NODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1269,
  serialized_end=1542,
)

_DAG_SYMBOLSENTRY.fields_by_name['value'].message_type = _NODE
_DAG_SYMBOLSENTRY.containing_type = _DAG
_DAG.fields_by_name['symbols'].message_type = _DAG_SYMBOLSENTRY
_DAG.fields_by_name['flowchart'].message_type = _FLOWCHART
_FLOWCHART_NODESENTRY.fields_by_name['value'].message_type = _NODE
_FLOWCHART_NODESENTRY.containing_type = _FLOWCHART
_FLOWCHART_EDGESENTRY.fields_by_name['value'].message_type = _EDGE
_FLOWCHART_EDGESENTRY.containing_type = _FLOWCHART
_FLOWCHART.fields_by_name['nodes'].message_type = _FLOWCHART_NODESENTRY
_FLOWCHART.fields_by_name['edges'].message_type = _FLOWCHART_EDGESENTRY
_EDGE.fields_by_name['type'].enum_type = _EDGE_EDGETYPE
_EDGE_EDGETYPE.containing_type = _EDGE
_RUNSTATUS_INPUTSENTRY.containing_type = _RUNSTATUS
_RUNSTATUS_OUTPUTSENTRY.containing_type = _RUNSTATUS
_RUNSTATUS.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RUNSTATUS.fields_by_name['end'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RUNSTATUS.fields_by_name['inputs'].message_type = _RUNSTATUS_INPUTSENTRY
_RUNSTATUS.fields_by_name['outputs'].message_type = _RUNSTATUS_OUTPUTSENTRY
_CODE_INPUTSENTRY.containing_type = _CODE
_CODE_OUTPUTSENTRY.containing_type = _CODE
_CODE.fields_by_name['inputs'].message_type = _CODE_INPUTSENTRY
_CODE.fields_by_name['outputs'].message_type = _CODE_OUTPUTSENTRY
_CODE.fields_by_name['conditions'].message_type = _CODE
_NODE.fields_by_name['type'].enum_type = _NODE_NODETYPE
_NODE.fields_by_name['info'].message_type = _CODE
_NODE.fields_by_name['run_status'].message_type = _RUNSTATUS
_NODE_NODETYPE.containing_type = _NODE
DESCRIPTOR.message_types_by_name['DAG'] = _DAG
DESCRIPTOR.message_types_by_name['Flowchart'] = _FLOWCHART
DESCRIPTOR.message_types_by_name['Edge'] = _EDGE
DESCRIPTOR.message_types_by_name['RunStatus'] = _RUNSTATUS
DESCRIPTOR.message_types_by_name['Code'] = _CODE
DESCRIPTOR.message_types_by_name['Node'] = _NODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DAG = _reflection.GeneratedProtocolMessageType('DAG', (_message.Message,), {

  'SymbolsEntry' : _reflection.GeneratedProtocolMessageType('SymbolsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DAG_SYMBOLSENTRY,
    '__module__' : 'dag_pb2'
    # @@protoc_insertion_point(class_scope:jobs.dag.DAG.SymbolsEntry)
    })
  ,
  'DESCRIPTOR' : _DAG,
  '__module__' : 'dag_pb2'
  # @@protoc_insertion_point(class_scope:jobs.dag.DAG)
  })
_sym_db.RegisterMessage(DAG)
_sym_db.RegisterMessage(DAG.SymbolsEntry)

Flowchart = _reflection.GeneratedProtocolMessageType('Flowchart', (_message.Message,), {

  'NodesEntry' : _reflection.GeneratedProtocolMessageType('NodesEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLOWCHART_NODESENTRY,
    '__module__' : 'dag_pb2'
    # @@protoc_insertion_point(class_scope:jobs.dag.Flowchart.NodesEntry)
    })
  ,

  'EdgesEntry' : _reflection.GeneratedProtocolMessageType('EdgesEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLOWCHART_EDGESENTRY,
    '__module__' : 'dag_pb2'
    # @@protoc_insertion_point(class_scope:jobs.dag.Flowchart.EdgesEntry)
    })
  ,
  'DESCRIPTOR' : _FLOWCHART,
  '__module__' : 'dag_pb2'
  # @@protoc_insertion_point(class_scope:jobs.dag.Flowchart)
  })
_sym_db.RegisterMessage(Flowchart)
_sym_db.RegisterMessage(Flowchart.NodesEntry)
_sym_db.RegisterMessage(Flowchart.EdgesEntry)

Edge = _reflection.GeneratedProtocolMessageType('Edge', (_message.Message,), {
  'DESCRIPTOR' : _EDGE,
  '__module__' : 'dag_pb2'
  # @@protoc_insertion_point(class_scope:jobs.dag.Edge)
  })
_sym_db.RegisterMessage(Edge)

RunStatus = _reflection.GeneratedProtocolMessageType('RunStatus', (_message.Message,), {

  'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNSTATUS_INPUTSENTRY,
    '__module__' : 'dag_pb2'
    # @@protoc_insertion_point(class_scope:jobs.dag.RunStatus.InputsEntry)
    })
  ,

  'OutputsEntry' : _reflection.GeneratedProtocolMessageType('OutputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNSTATUS_OUTPUTSENTRY,
    '__module__' : 'dag_pb2'
    # @@protoc_insertion_point(class_scope:jobs.dag.RunStatus.OutputsEntry)
    })
  ,
  'DESCRIPTOR' : _RUNSTATUS,
  '__module__' : 'dag_pb2'
  # @@protoc_insertion_point(class_scope:jobs.dag.RunStatus)
  })
_sym_db.RegisterMessage(RunStatus)
_sym_db.RegisterMessage(RunStatus.InputsEntry)
_sym_db.RegisterMessage(RunStatus.OutputsEntry)

Code = _reflection.GeneratedProtocolMessageType('Code', (_message.Message,), {

  'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CODE_INPUTSENTRY,
    '__module__' : 'dag_pb2'
    # @@protoc_insertion_point(class_scope:jobs.dag.Code.InputsEntry)
    })
  ,

  'OutputsEntry' : _reflection.GeneratedProtocolMessageType('OutputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CODE_OUTPUTSENTRY,
    '__module__' : 'dag_pb2'
    # @@protoc_insertion_point(class_scope:jobs.dag.Code.OutputsEntry)
    })
  ,
  'DESCRIPTOR' : _CODE,
  '__module__' : 'dag_pb2'
  # @@protoc_insertion_point(class_scope:jobs.dag.Code)
  })
_sym_db.RegisterMessage(Code)
_sym_db.RegisterMessage(Code.InputsEntry)
_sym_db.RegisterMessage(Code.OutputsEntry)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'dag_pb2'
  # @@protoc_insertion_point(class_scope:jobs.dag.Node)
  })
_sym_db.RegisterMessage(Node)


DESCRIPTOR._options = None
_DAG_SYMBOLSENTRY._options = None
_FLOWCHART_NODESENTRY._options = None
_FLOWCHART_EDGESENTRY._options = None
_RUNSTATUS_INPUTSENTRY._options = None
_RUNSTATUS_OUTPUTSENTRY._options = None
_CODE_INPUTSENTRY._options = None
_CODE_OUTPUTSENTRY._options = None
# @@protoc_insertion_point(module_scope)
