# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nbox_ws.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import job_pb2 as job__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='nbox_ws.proto',
  package='jobs.ws',
  syntax='proto3',
  serialized_options=b'Z0github.com/NimbleBoxAI/jobs-architecture/jobs_pb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rnbox_ws.proto\x12\x07jobs.ws\x1a\tjob.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"1\n\x07JobInfo\x12\x0e\n\x02id\x18\x01 \x01(\tB\x02\x18\x01\x12\x16\n\x03job\x18\x02 \x01(\x0b\x32\t.jobs.Job\"^\n\x0fListJobsRequest\x12$\n\tauth_info\x18\x01 \x01(\x0b\x32\x11.jobs.NBXAuthInfo\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"D\n\x10ListJobsResponse\x12\x17\n\x04Jobs\x18\x01 \x03(\x0b\x32\t.jobs.Job\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\x11UploadCodeRequest\x12\x16\n\x03job\x18\x01 \x01(\x0b\x32\t.jobs.Job\x12\x1f\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x11.jobs.NBXAuthInfo\"*\n\x10\x43reateJobRequest\x12\x16\n\x03job\x18\x03 \x01(\x0b\x32\t.jobs.Job\"[\n\x10UpdateJobRequest\x12\x16\n\x03job\x18\x01 \x01(\x0b\x32\t.jobs.Job\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"_\n\x0eJobLogsRequest\x12\x1d\n\x03job\x18\x01 \x01(\x0b\x32\x10.jobs.ws.JobInfo\x12\x1f\n\x08k8s_info\x18\x02 \x01(\x0b\x32\r.jobs.K8sInfo\x12\r\n\x05lines\x18\x03 \x01(\x05\"U\n\x06JobLog\x12\x1d\n\x03job\x18\x01 \x01(\x0b\x32\x10.jobs.ws.JobInfo\x12\x1f\n\x08k8s_info\x18\x02 \x01(\x0b\x32\r.jobs.K8sInfo\x12\x0b\n\x03log\x18\x03 \x03(\t\"z\n\x10UpdateRunRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x16\n\x03job\x18\x02 \x01(\x0b\x32\t.jobs.Job\x12.\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x04 \x01(\t2\xd4\x04\n\x0cWSJobService\x12\'\n\x06GetJob\x12\x10.jobs.ws.JobInfo\x1a\t.jobs.Job\"\x00\x12\x41\n\x08ListJobs\x12\x18.jobs.ws.ListJobsRequest\x1a\x19.jobs.ws.ListJobsResponse\"\x00\x12\x38\n\rUploadJobCode\x12\x1a.jobs.ws.UploadCodeRequest\x1a\t.jobs.Job\"\x00\x12\x33\n\tCreateJob\x12\x19.jobs.ws.CreateJobRequest\x1a\t.jobs.Job\"\x00\x12\x33\n\tUpdateJob\x12\x19.jobs.ws.UpdateJobRequest\x1a\t.jobs.Job\"\x00\x12\x37\n\tDeleteJob\x12\x10.jobs.ws.JobInfo\x1a\x16.google.protobuf.Empty\"\x00\x12:\n\nGetJobLogs\x12\x17.jobs.ws.JobLogsRequest\x1a\x0f.jobs.ws.JobLog\"\x00\x30\x01\x12<\n\nTriggerJob\x12\x10.jobs.ws.JobInfo\x1a\x1a.google.protobuf.BoolValue\"\x00\x12@\n\tUpdateRun\x12\x19.jobs.ws.UpdateRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12?\n\x0bGetRunToken\x12\x10.jobs.ws.JobInfo\x1a\x1c.google.protobuf.StringValue\"\x00\x42\x32Z0github.com/NimbleBoxAI/jobs-architecture/jobs_pbb\x06proto3'
  ,
  dependencies=[job__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_JOBINFO = _descriptor.Descriptor(
  name='JobInfo',
  full_name='jobs.ws.JobInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='jobs.ws.JobInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job', full_name='jobs.ws.JobInfo.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=214,
)


_LISTJOBSREQUEST = _descriptor.Descriptor(
  name='ListJobsRequest',
  full_name='jobs.ws.ListJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_info', full_name='jobs.ws.ListJobsRequest.auth_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='jobs.ws.ListJobsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='jobs.ws.ListJobsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=310,
)


_LISTJOBSRESPONSE = _descriptor.Descriptor(
  name='ListJobsResponse',
  full_name='jobs.ws.ListJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Jobs', full_name='jobs.ws.ListJobsResponse.Jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='jobs.ws.ListJobsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=380,
)


_UPLOADCODEREQUEST = _descriptor.Descriptor(
  name='UploadCodeRequest',
  full_name='jobs.ws.UploadCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='jobs.ws.UploadCodeRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth', full_name='jobs.ws.UploadCodeRequest.auth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=458,
)


_CREATEJOBREQUEST = _descriptor.Descriptor(
  name='CreateJobRequest',
  full_name='jobs.ws.CreateJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='jobs.ws.CreateJobRequest.job', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=502,
)


_UPDATEJOBREQUEST = _descriptor.Descriptor(
  name='UpdateJobRequest',
  full_name='jobs.ws.UpdateJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='jobs.ws.UpdateJobRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='jobs.ws.UpdateJobRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=595,
)


_JOBLOGSREQUEST = _descriptor.Descriptor(
  name='JobLogsRequest',
  full_name='jobs.ws.JobLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='jobs.ws.JobLogsRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k8s_info', full_name='jobs.ws.JobLogsRequest.k8s_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lines', full_name='jobs.ws.JobLogsRequest.lines', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=692,
)


_JOBLOG = _descriptor.Descriptor(
  name='JobLog',
  full_name='jobs.ws.JobLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='jobs.ws.JobLog.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k8s_info', full_name='jobs.ws.JobLog.k8s_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log', full_name='jobs.ws.JobLog.log', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=694,
  serialized_end=779,
)


_UPDATERUNREQUEST = _descriptor.Descriptor(
  name='UpdateRunRequest',
  full_name='jobs.ws.UpdateRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='jobs.ws.UpdateRunRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job', full_name='jobs.ws.UpdateRunRequest.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='jobs.ws.UpdateRunRequest.updated_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='jobs.ws.UpdateRunRequest.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=781,
  serialized_end=903,
)

_JOBINFO.fields_by_name['job'].message_type = job__pb2._JOB
_LISTJOBSREQUEST.fields_by_name['auth_info'].message_type = job__pb2._NBXAUTHINFO
_LISTJOBSRESPONSE.fields_by_name['Jobs'].message_type = job__pb2._JOB
_UPLOADCODEREQUEST.fields_by_name['job'].message_type = job__pb2._JOB
_UPLOADCODEREQUEST.fields_by_name['auth'].message_type = job__pb2._NBXAUTHINFO
_CREATEJOBREQUEST.fields_by_name['job'].message_type = job__pb2._JOB
_UPDATEJOBREQUEST.fields_by_name['job'].message_type = job__pb2._JOB
_UPDATEJOBREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_JOBLOGSREQUEST.fields_by_name['job'].message_type = _JOBINFO
_JOBLOGSREQUEST.fields_by_name['k8s_info'].message_type = job__pb2._K8SINFO
_JOBLOG.fields_by_name['job'].message_type = _JOBINFO
_JOBLOG.fields_by_name['k8s_info'].message_type = job__pb2._K8SINFO
_UPDATERUNREQUEST.fields_by_name['job'].message_type = job__pb2._JOB
_UPDATERUNREQUEST.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['JobInfo'] = _JOBINFO
DESCRIPTOR.message_types_by_name['ListJobsRequest'] = _LISTJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListJobsResponse'] = _LISTJOBSRESPONSE
DESCRIPTOR.message_types_by_name['UploadCodeRequest'] = _UPLOADCODEREQUEST
DESCRIPTOR.message_types_by_name['CreateJobRequest'] = _CREATEJOBREQUEST
DESCRIPTOR.message_types_by_name['UpdateJobRequest'] = _UPDATEJOBREQUEST
DESCRIPTOR.message_types_by_name['JobLogsRequest'] = _JOBLOGSREQUEST
DESCRIPTOR.message_types_by_name['JobLog'] = _JOBLOG
DESCRIPTOR.message_types_by_name['UpdateRunRequest'] = _UPDATERUNREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JobInfo = _reflection.GeneratedProtocolMessageType('JobInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFO,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.JobInfo)
  })
_sym_db.RegisterMessage(JobInfo)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

UploadCodeRequest = _reflection.GeneratedProtocolMessageType('UploadCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADCODEREQUEST,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.UploadCodeRequest)
  })
_sym_db.RegisterMessage(UploadCodeRequest)

CreateJobRequest = _reflection.GeneratedProtocolMessageType('CreateJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEJOBREQUEST,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.CreateJobRequest)
  })
_sym_db.RegisterMessage(CreateJobRequest)

UpdateJobRequest = _reflection.GeneratedProtocolMessageType('UpdateJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEJOBREQUEST,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.UpdateJobRequest)
  })
_sym_db.RegisterMessage(UpdateJobRequest)

JobLogsRequest = _reflection.GeneratedProtocolMessageType('JobLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBLOGSREQUEST,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.JobLogsRequest)
  })
_sym_db.RegisterMessage(JobLogsRequest)

JobLog = _reflection.GeneratedProtocolMessageType('JobLog', (_message.Message,), {
  'DESCRIPTOR' : _JOBLOG,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.JobLog)
  })
_sym_db.RegisterMessage(JobLog)

UpdateRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNREQUEST,
  '__module__' : 'nbox_ws_pb2'
  # @@protoc_insertion_point(class_scope:jobs.ws.UpdateRunRequest)
  })
_sym_db.RegisterMessage(UpdateRunRequest)


DESCRIPTOR._options = None
_JOBINFO.fields_by_name['id']._options = None

_WSJOBSERVICE = _descriptor.ServiceDescriptor(
  name='WSJobService',
  full_name='jobs.ws.WSJobService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=906,
  serialized_end=1502,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetJob',
    full_name='jobs.ws.WSJobService.GetJob',
    index=0,
    containing_service=None,
    input_type=_JOBINFO,
    output_type=job__pb2._JOB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListJobs',
    full_name='jobs.ws.WSJobService.ListJobs',
    index=1,
    containing_service=None,
    input_type=_LISTJOBSREQUEST,
    output_type=_LISTJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UploadJobCode',
    full_name='jobs.ws.WSJobService.UploadJobCode',
    index=2,
    containing_service=None,
    input_type=_UPLOADCODEREQUEST,
    output_type=job__pb2._JOB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateJob',
    full_name='jobs.ws.WSJobService.CreateJob',
    index=3,
    containing_service=None,
    input_type=_CREATEJOBREQUEST,
    output_type=job__pb2._JOB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateJob',
    full_name='jobs.ws.WSJobService.UpdateJob',
    index=4,
    containing_service=None,
    input_type=_UPDATEJOBREQUEST,
    output_type=job__pb2._JOB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteJob',
    full_name='jobs.ws.WSJobService.DeleteJob',
    index=5,
    containing_service=None,
    input_type=_JOBINFO,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobLogs',
    full_name='jobs.ws.WSJobService.GetJobLogs',
    index=6,
    containing_service=None,
    input_type=_JOBLOGSREQUEST,
    output_type=_JOBLOG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TriggerJob',
    full_name='jobs.ws.WSJobService.TriggerJob',
    index=7,
    containing_service=None,
    input_type=_JOBINFO,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRun',
    full_name='jobs.ws.WSJobService.UpdateRun',
    index=8,
    containing_service=None,
    input_type=_UPDATERUNREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRunToken',
    full_name='jobs.ws.WSJobService.GetRunToken',
    index=9,
    containing_service=None,
    input_type=_JOBINFO,
    output_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WSJOBSERVICE)

DESCRIPTOR.services_by_name['WSJobService'] = _WSJOBSERVICE

# @@protoc_insertion_point(module_scope)
